==> kubernetes-model-apiextensions-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceSubresourceStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceSubresourceStatusBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceSubresourceStatusBuilder() { 
        this(true);
    }


    public CustomResourceSubresourceStatusBuilder(Boolean validationEnabled) { 
        this(new CustomResourceSubresourceStatus(), validationEnabled);
    }


    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent) { 
        this(fluent, true);
    }


    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new CustomResourceSubresourceStatus(), validationEnabled);
    }


    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance) { 
        this(fluent, instance, true);
    }


    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        this.validationEnabled = validationEnabled; 
    }


    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance) { 
        this(instance,true);
    }


    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus build() {
        CustomResourceSubresourceStatus buildable = new CustomResourceSubresourceStatus();
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceSubresourceStatusBuilder that = (CustomResourceSubresourceStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.4.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceSubresourceStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceSubresourceStatusBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public CustomResourceSubresourceStatusBuilder() {
        this(true);
    }

    public CustomResourceSubresourceStatusBuilder(java.lang.Boolean validationEnabled) {
        this(new CustomResourceSubresourceStatus(), validationEnabled);
    }

    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new CustomResourceSubresourceStatus(), validationEnabled);
    }

    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance) {
        this(fluent, instance, true);
    }

    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance) {
        this(instance,true);
    }

    public CustomResourceSubresourceStatusBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceStatus build() {
        CustomResourceSubresourceStatus buildable = new CustomResourceSubresourceStatus();
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceSubresourceStatusBuilder that = (CustomResourceSubresourceStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
